#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-10-31
# File  : cisco_meraki_org_device_uplinks.py (inventory plugin)

# inventory of cisco Meraki uplinks

from collections.abc import Sequence

from cmk.base.plugins.agent_based.agent_based_api.v1 import register, TableRow
from cmk.base.plugins.agent_based.agent_based_api.v1.type_defs import InventoryResult, StringTable
from cmk.base.plugins.agent_based.utils.cisco_meraki import load_json


__uplinks = [
    {
        "addresses": [
            {
                "address": "192.168.20.3",
                "assignmentMode": "static",
                "gateway": "192.168.20.1",
                "protocol": "ipv4",
                "public": {
                    "address": "87.129.136.2"
                }
            }
        ],
        "interface": "man1"
    }
]


def parse_device_uplinks(string_table: StringTable) -> Sequence | None:
    return loaded_json[0]['uplinks'] if (loaded_json := load_json(string_table)) else None


register.agent_section(
    name="cisco_meraki_org_device_uplinks_info",
    parse_function=parse_device_uplinks,
)


def inventory_device_uplinks(section: Sequence | None) -> InventoryResult:
    path = ['networking', 'uplinks']
    for uplink in section:
        interface = uplink['interface']
        for address in uplink['addresses']:
            key_columns = {
                'interface': interface,
                'protocol': address['protocol'],
                'address': address['address'],
            }
            inventory_columns = {
                'assignment_mode': address['assignmentMode'],
                'gateway': address['gateway'],
                'public_address': address['public']['address'],
            }
            yield TableRow(
                path=path,
                key_columns=key_columns,
                inventory_columns=inventory_columns
            )
        pass


register.inventory_plugin(
    name="cisco_meraki_org_device_uplinks_info",
    inventory_function=inventory_device_uplinks,
)
