#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-11-04
# File  : cisco_meraki.py (metrics)
#
# 2023-11-12: added wireless device status (channel, channel width, signal power)

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics.utils import (
    metric_info,
    graph_info,
    perfometer_info
)

#
# license overview
#
metric_info['sum_licensed_devices'] = {
    'title': _('Licensed devices'),
    'unit': 'count',
    'color': '31/a',
}

metric_info['remaining_time'] = {
    'title': _('Remaining time'),
    'unit': 's',
    'color': '26/a',
}

graph_info['cisco_meraki.remaining_time'] = {
    'title': _('Cisco Meraki Licenses remaining time'),
    'metrics': [
        ('remaining_time', 'area'),
    ],
    'scalars': [
        ('remaining_time:crit', _('crit')),
        ('remaining_time:warn', _('warn')),
    ],
    'range': (0, 'remaining_time:max'),
}

graph_info['cisco_meraki.licensed_devices'] = {
    'title': _('Cisco Meraki Licensed devices'),
    'metrics': [
        ('sum_licensed_devices', 'area'),
    ],
    'range': (0, 'sum_licensed_devices:max'),
}

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'remaining_time',
        # 'half_value': 2592000.0,  # ome month
        'half_value': 31104000.0,  # ome year
        'exponent': 2,
    },
    {
        'type': 'logarithmic',
        'metric': 'sum_licensed_devices',
        'half_value': 500.0,
        'exponent': 2,
    }
]))

#
# device_status
#
metric_info['last_reported'] = {
    'title': _('Last reported'),
    'unit': 's',
    'color': '26/a',
}

graph_info['cisco_meraki.device_status'] = {
    'title': _('Cisco Meraki device status'),
    'metrics': [
        ('last_reported', 'area'),
    ],
    'range': (0, 'last_reported:max'),
    'scalars': [
        ('last_reported:crit', _('crit')),
        ('last_reported:warn', _('warn')),
    ],
}

perfometer_info.append({
    'type': 'logarithmic',
    'metric': 'last_reported',
    'half_value': 7200,  # 2 hours
    'exponent': 2,
})

#
# wireless devices status
#
metric_info["signal_power"] = {
    "title": _("Power"),
    "unit": "dbm",
    "color": "#20c080",
}

metric_info["channel_width"] = {
    "title": _("Channel Width"),
    "unit": "hz",
    "color": "11/a",
}

metric_info["channel"] = {
    "title": _("Channel"),
    "unit": "count",
    "color": "21/a",
}

graph_info['cisco_meraki.wireless_device_status.signal_power'] = {
    'title': _('Signal power'),
    'metrics': [
        ('signal_power', 'area'),
    ],
    'range': (0, 'signal_power:max'),
}

graph_info['cisco_meraki.wireless_device_status.channel_width'] = {
    'title': _('Channel Width'),
    'metrics': [
        ('channel_width', 'area'),
    ],
    'range': (0, 'channel_width:max'),
}

graph_info['cisco_meraki.wireless_device_status.channel'] = {
    'title': _('Channel'),
    'metrics': [
        ('channel', 'area'),
    ],
    'range': (0, 'channel:max'),
}

perfometer_info.append({
    'type': 'linear',
    'segments': ['signal_power'],
    'total': "signal_power",
})
