#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-11-05
# File  : cisco_meraki_org_appliance_vpns.py (WATO)

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)
from cmk.gui.valuespec import (
    Dictionary,
    TextInput,
    MonitoringState,
)


def _parameter_valuespec_cisco_meraki_org_appliance_vpns():
    return Dictionary(
        title=_('Cisco Meraki Appliance VPNs'),
        optional_keys=True,
        elements=[
            ('status_not_reachable',
             MonitoringState(
                 title=_('Monitoring state if the VPN peer is not "reachable"'),
                 default_value=1,
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        title=lambda: _('Cisco Meraki Appliance VPNs'),
        check_group_name='cisco_meraki_org_appliance_vpns',
        group=RulespecGroupCheckParametersNetworking,
        parameter_valuespec=_parameter_valuespec_cisco_meraki_org_appliance_vpns,
        match_type='dict',
        item_spec=lambda: TextInput(
            title=_('The peer name'),
        ),
    )
)
