#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-11-04
# File  : cisco_meraki_org_device_status.py (WATO)

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersHardware,
)
from cmk.gui.valuespec import (
    Integer,
    Dictionary,
    TextInput,
    Tuple,
    MonitoringState,
)


#
# Cisco Meraki Device Status
#
def _parameter_valuespec_cisco_meraki_device_status():
    return Dictionary(
        title=_("Cisco Meraki Device status"),
        optional_keys=True,
        elements=[
            ('last_reported_upper_levels',
             Tuple(
                 title=_('Max time for last reported'),
                 elements=[
                     Integer(title=_('Warning at'), minvalue=0, unit=_('hours'), size=5),
                     Integer(title=_('Critical at'), minvalue=0, unit=_('hours'), size=5),
                 ],
             )),
            ('status_map',
             Dictionary(
                 title=_('Map device status to monitoring state'),
                 elements=[
                     ("online",
                      MonitoringState(
                          title=_('Monitoring state for device state "online"'),
                          default_value=0,
                      )),
                     ("alerting",
                      MonitoringState(
                          title=_('Monitoring state for device state "alerting"'),
                          default_value=2,
                      )),
                     ("offline",
                      MonitoringState(
                          title=_('Monitoring state for device state "offline"'),
                          default_value=1,
                      )),
                     ("dormant",
                      MonitoringState(
                          title=_('Monitoring state for device state "dormant"'),
                          default_value=1,
                      )),
                 ]
             ))
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        title=lambda: _("Cisco Meraki Device status"),
        check_group_name="cisco_meraki_device_status",
        group=RulespecGroupCheckParametersHardware,
        parameter_valuespec=_parameter_valuespec_cisco_meraki_device_status,
        match_type="dict",
    )
)


#
# Cisco Meraki Power Supply
#
def _parameter_valuespec_cisco_meraki_device_status_ps():
    return Dictionary(
        title=_("Cisco Meraki Powersupply status"),
        optional_keys=True,
        elements=[
            ("state_not_powering",
             MonitoringState(
                 title=_('Monitoring state if power supply is not "powering"'),
                 default_value=1,
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        title=lambda: _("Cisco Meraki Power supply"),
        check_group_name="cisco_meraki_device_status_ps",
        group=RulespecGroupCheckParametersHardware,
        parameter_valuespec=_parameter_valuespec_cisco_meraki_device_status_ps,
        match_type="dict",
        item_spec=lambda: TextInput(
            title=_("The Slot number"),
        ),
    )
)
