#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2024-02-02
# File  : cisco_meraki_org_wireless_status.py (WATO)

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)
from cmk.gui.valuespec import (
    Dictionary,
    TextInput,
    MonitoringState,
)


def _parameter_valuespec_cisco_meraki_wireless_status():
    return Dictionary(
        title=_('Cisco Meraki Appliance Uplinks'),
        optional_keys=True,
        elements=[
            ('state_if_not_enabled',
             MonitoringState(
                 title=_('Monitoring state if SSID is "not enabled"'),
                 default_value=1,
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        title=lambda: _('Cisco Meraki Wireless device'),
        check_group_name='cisco_meraki_wireless_device_status',
        group=RulespecGroupCheckParametersNetworking,
        parameter_valuespec=_parameter_valuespec_cisco_meraki_wireless_status,
        match_type='dict',
        item_spec=lambda: TextInput(title=_('The SSID'), ),
    )
)
