#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-11-11
# File  : cisco_meraki_organisations.py (wato plugin)

# 2023-11-18: split from cisco_meraki_org_licenses_overview.py


from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    rulespec_registry,
    HostRulespec,
    RulespecGroupCheckParametersDiscovery,
    DropdownChoice,
)
from cmk.gui.valuespec import (
    Dictionary,
)


def _valuespec_discovery_meraki_organisations():
    return Dictionary(
        title=_('Cisco Meraki Organisations (API/Licenses)'),
        elements=[
            ('item_variant',
             DropdownChoice(
                 title=_('Information to use as item'),
                 help=_(
                     'You can select how to build the item for this service. By default the Organisation ID/name\n'
                     'is used to stay compatible with the build in check. The information not used for the item\n'
                     'will be added to the service output.'
                 ),
                 choices=[
                     ('org_id', 'Organisation ID'),
                     ('org_name', 'Organisation name'),
                     ('org_id_name', 'Organisation ID/name'),
                 ],
                 default_value='org_id_name',
             )),
        ],
        required_keys=['item_variant'],
    )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupCheckParametersDiscovery,
        match_type='dict',
        name='discovery_meraki_organisations',
        valuespec=_valuespec_discovery_meraki_organisations,
    ))
