#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-11-18
# File  : cisco_meraki_organisations_api.py (wato plugin)

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersApplications,
)
from cmk.gui.valuespec import (
    Dictionary,
    TextInput,
    MonitoringState,
)


def _parameter_valuespec_cisco_meraki_organisations_api():
    return Dictionary(
        title=_("Cisco Meraki Organisation API"),
        optional_keys=True,
        elements=[
            ("state_api_not_enabled",
             MonitoringState(
                 title=_('Monitoring state if API is not enabled'),
                 default_value=1,
             )),
        ],
        ignored_keys=[
            'internal_item_name',
            'old_item_name',
            'item_variant',
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        title=lambda: _("Cisco Meraki Organisation API"),
        check_group_name="cisco_meraki_organisations_api",
        group=RulespecGroupCheckParametersApplications,
        parameter_valuespec=_parameter_valuespec_cisco_meraki_organisations_api,
        item_spec=lambda: TextInput(
            title=_("The organisation"),
        ),
        match_type="dict",
    )
)
