#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2024-02-02
# File  : cisco_meraki_switch_ports_statuses.py (WATO)

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)
from cmk.gui.valuespec import (
    Dictionary,
    TextInput,
    MonitoringState,
)


def _parameter_valuespec_cisco_meraki_switch_ports_statuses():
    return Dictionary(
        title=_('Cisco Meraki Appliance Uplinks'),
        optional_keys=True,
        elements=[
            ('state_disabled',
             MonitoringState(
                 title=_('Monitoring state if port is "disabled"'),
                 default_value=0,
             )),
            ('state_not_connected',
             MonitoringState(
                 title=_('Monitoring state if port is "not connected"'),
                 default_value=0,
             )),
            ('state_not_full_duplex',
             MonitoringState(
                 title=_('Monitoring state if port is "not full duplex"'),
                 default_value=1,
             )),
            ('state_speed_change',
             MonitoringState(
                 title=_('Monitoring state if speed is changed'),
                 default_value=1,
             )),
            ('state_admin_change',
             MonitoringState(
                 title=_('Monitoring state if admin state is changed'),
                 default_value=1,
             )),
            ('state_op_change',
             MonitoringState(
                 title=_('Monitoring state if operational state is changed'),
                 default_value=1,
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        title=lambda: _('Cisco Meraki Switch Ports'),
        check_group_name='cisco_meraki_switch_ports_statuses',
        group=RulespecGroupCheckParametersNetworking,
        parameter_valuespec=_parameter_valuespec_cisco_meraki_switch_ports_statuses,
        match_type='dict',
        item_spec=lambda: TextInput(title=_('The Port ID'), ),
    )
)
